==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/SaveEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveEvaluationPlan] (
	@Instance Varchar(50) = NULL,
	@ID Varchar(50) = NULL,
	@Modality Varchar(50) = NULL,
	@DateFin Datetime = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@IdEvaluationFormat Varchar(50) = NULL,
	@TranscriptionLanguage VARCHAR(25) = NULL,
	@EnvironmentId VARCHAR(100) = NULL,
	@Description Varchar(200) = NULL,
	@Enabled Bit = NULL,

	@FilterByContent BIT = NULL,
	@FilterByContentPercentage NUMERIC(3,0) = NULL,
	@EvaluatePercentage NUMERIC(3,0) = NULL,
	@ProcessAndEvaluate BIT = NULL,
	@FilterByContentQueryName VARCHAR(50) = NULL,
	@FilterByContentQuery VARCHAR(1000) = NULL,
	@EvaluationStarted BIT = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@Status	NUMERIC(2,0) = NULL,
	@Evaluation_Mode VARCHAR(10) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [EvaluationPlan]
	SET
		[Modality] = @Modality,
		[DateFin] = @DateFin,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE(),
		[IdEvaluationFormat] = @IdEvaluationFormat,
		[TranscriptionLanguage] = @TranscriptionLanguage,
		[EnvironmentId] = @EnvironmentId,
		[Description] =@Description,
		[Enabled] = CASE WHEN @Enabled IS NULL THEN [Enabled] ELSE @Enabled END,
		[EvaluatePercentage] = @EvaluatePercentage,
		[ProcessAndEvaluate] = @ProcessAndEvaluate,
		[FilterByContent] = CASE WHEN @FilterByContent IS NULL THEN [FilterByContent] ELSE @FilterByContent END,
		[FilterByContentPercentage] = CASE WHEN @FilterByContentPercentage IS NULL THEN [FilterByContentPercentage] ELSE @FilterByContentPercentage END,
		[FilterByContentQueryName] = CASE WHEN @FilterByContentQueryName IS NULL THEN [FilterByContentQueryName] ELSE @FilterByContentQueryName END,
		[FilterByContentQuery] = CASE WHEN @FilterByContentQuery IS NULL THEN [FilterByContentQuery] ELSE @FilterByContentQuery END,
		
		[EvaluationStarted] = @EvaluationStarted,
		[ProcessId] = @ProcessId,
		[Status] = @Status,
		[Total] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Total] END,
		[Progress] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Progress] END,
		[Error] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Error] END,
		[Percentage] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Percentage] END,
		[Evaluation_Mode] = @Evaluation_Mode
	WHERE [Instance] = @Instance
    AND [ID] = @ID

    IF @@ROWCOUNT = 0
    BEGIN 
	    		INSERT INTO [EvaluationPlan] (
				[Instance],[ID],
				[Modality], [DateFin], [CreatedDate],
				[CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
				[TimeStamp], [IdEvaluationFormat], [TranscriptionLanguage],
				[EnvironmentId], [Description], [Enabled],
				[FilterByContent], [FilterByContentPercentage], [EvaluatePercentage], [ProcessAndEvaluate], [FilterByContentQueryName], [FilterByContentQuery], [EvaluationStarted], [ProcessId],
				[Status],[Evaluation_Mode]
				)
			   VALUES (
				@Instance,@ID,
				@Modality, @DateFin, @CreatedDate,
				@CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
				GETUTCDATE(), @IdEvaluationFormat, @TranscriptionLanguage,
				@EnvironmentId, @Description, 1,
				@FilterByContent, @FilterByContentPercentage, @EvaluatePercentage, @ProcessAndEvaluate, @FilterByContentQueryName, @FilterByContentQuery, @EvaluationStarted, @ProcessId,
				@Status, @Evaluation_Mode
			   )
			   
			 EXEC [dbo].[SaveHistoricEvaluationPlanData] @Instance,@ID,@IdEvaluationFormat
    END

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.6.0_database.tar.gz: database/mssql/procedures/SaveEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveEvaluationPlan] (
	@Instance Varchar(50) = NULL,
	@ID Varchar(50) = NULL,
	@Modality Varchar(50) = NULL,
	@DateFin Datetime = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@IdEvaluationFormat Varchar(50) = NULL,
	@TranscriptionLanguage VARCHAR(25) = NULL,
	@EnvironmentId VARCHAR(100) = NULL,
	@Description Varchar(200) = NULL,
	@Enabled Bit = NULL,

	@FilterByContent BIT = NULL,
	@FilterByContentPercentage NUMERIC(3,0) = NULL,
	@EvaluatePercentage NUMERIC(3,0) = NULL,
	@ProcessAndEvaluate BIT = NULL,
	@FilterByContentQueryName VARCHAR(50) = NULL,
	@FilterByContentQuery VARCHAR(1000) = NULL,
	@EvaluationStarted BIT = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@Status	NUMERIC(2,0) = NULL,
	@Evaluation_Mode VARCHAR(10) = NULL,
	@BatchScheduleId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [EvaluationPlan]
	SET
		[Modality] = @Modality,
		[DateFin] = @DateFin,
		[IdEvaluationFormat] = @IdEvaluationFormat,
		[TranscriptionLanguage] = @TranscriptionLanguage,
		[EnvironmentId] = @EnvironmentId,
		[Description] =@Description,
		[Enabled] = CASE WHEN @Enabled IS NULL THEN [Enabled] ELSE @Enabled END,
		[EvaluatePercentage] = @EvaluatePercentage,
		[ProcessAndEvaluate] = @ProcessAndEvaluate,
		[FilterByContent] = CASE WHEN @FilterByContent IS NULL THEN [FilterByContent] ELSE @FilterByContent END,
		[FilterByContentPercentage] = CASE WHEN @FilterByContentPercentage IS NULL THEN [FilterByContentPercentage] ELSE @FilterByContentPercentage END,
		[FilterByContentQueryName] = CASE WHEN @FilterByContentQueryName IS NULL THEN [FilterByContentQueryName] ELSE @FilterByContentQueryName END,
		[FilterByContentQuery] = CASE WHEN @FilterByContentQuery IS NULL THEN [FilterByContentQuery] ELSE @FilterByContentQuery END,
		
		[EvaluationStarted] = @EvaluationStarted,
		[ProcessId] = @ProcessId,
		[Status] = @Status,
		[Total] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Total] END,
		[Progress] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Progress] END,
		[Error] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Error] END,
		[Percentage] = CASE WHEN [Status] = 5 AND @Status = 1 THEN NULL ELSE [Percentage] END,
		[Evaluation_Mode] = @Evaluation_Mode,
		
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[LastModifiedDate] = GETUTCDATE(),
		[TimeStamp] = GETUTCDATE()
	WHERE [Instance] = @Instance
    AND [ID] = @ID

    IF @@ROWCOUNT = 0
    BEGIN 
		INSERT INTO [EvaluationPlan] (
			[Instance], [ID], [Modality], [DateFin], 
			[IdEvaluationFormat], [TranscriptionLanguage], [EnvironmentId], [Description], 
			[Enabled], [FilterByContent], [FilterByContentPercentage], [EvaluatePercentage], 
			[ProcessAndEvaluate], [FilterByContentQueryName], [FilterByContentQuery], [EvaluationStarted], 
			[ProcessId], [Status], [Evaluation_Mode], [BatchScheduleId],
				
			[CreatedByUserId], [CreatedDate], [TimeStamp]
		)
		VALUES (
			@Instance, @ID, @Modality, @DateFin, 
			@IdEvaluationFormat, @TranscriptionLanguage, @EnvironmentId, @Description, 
			1, @FilterByContent, @FilterByContentPercentage, @EvaluatePercentage, 
			@ProcessAndEvaluate, @FilterByContentQueryName, @FilterByContentQuery, @EvaluationStarted, 
			@ProcessId, @Status, @Evaluation_Mode, @BatchScheduleId,
				
			@CreatedByUserId, GETUTCDATE(), GETUTCDATE()
		)
			   
		EXEC [dbo].[SaveHistoricEvaluationPlanData] @Instance,@ID,@IdEvaluationFormat
    END

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
